pub struct Integer(NumericUnion<(), i32, CalcNumeric>);Expand description
A specified <integer>, either a simple integer value, a resolved calc expression,
or a full calc expression tree that cannot be computed at parse time.
Note that a calc expression may not actually be an integer; it will be rounded
at computed-value time.
Tuple Fields
0: NumericUnion<(), i32, CalcNumeric>Implementations
Sourceimpl Integer
impl Integer
Sourcepub fn new(val: CSSInteger) -> Self
pub fn new(val: CSSInteger) -> Self
Trivially constructs a new Integer value.
Sourcepub fn get(&self) -> Option<CSSInteger>
pub fn get(&self) -> Option<CSSInteger>
Returns the value if this is a plain (non-calc) integer, or None otherwise.
Use resolve() to also handle resolvable calc expressions, or to_computed_value()
when computed context is available.
Sourcepub fn resolve(&self) -> Option<CSSInteger>
pub fn resolve(&self) -> Option<CSSInteger>
Returns the value if it can be resolved at parse time, including resolvable calc expressions. Returns None for calc expressions that require computed-value context.
Sourcepub fn ensure_clamping_mode(
&mut self,
clamping_mode: AllowedNumericType,
) -> Result<(), ()>
pub fn ensure_clamping_mode( &mut self, clamping_mode: AllowedNumericType, ) -> Result<(), ()>
Makes sure this number matches the clamping, or errors otherwise.
Sourceimpl Integer
impl Integer
Sourcepub fn parse_non_negative<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
) -> Result<Integer, ParseError<'i>>
pub fn parse_non_negative<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<Integer, ParseError<'i>>
Parse a non-negative integer.
Sourcepub fn parse_positive<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
) -> Result<Integer, ParseError<'i>>
pub fn parse_positive<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<Integer, ParseError<'i>>
Parse a positive integer (>= 1).